@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.21';
+  $App::Pocoirc::VERSION = '0.22';
 }
 
 use strict;
@@ -398,7 +398,7 @@ sub quit_timeout {
 
 =head1 NAME
 
-App::Pocoirc - A command line tool for launching L<POE::Component::IRC|POE::Component::IRC> clients
+App::Pocoirc - A command line tool for launching POE::Component::IRC clients
 
 =head1 DESCRIPTION
 
